@@ -23,6 +23,7 @@
 #include "mutt.h"
 #include "mx.h"	/* for M_IMAP */
 #include "imap_private.h"
+#include "imap_ssl.h"
 
 #include <stdlib.h>
 #include <ctype.h>
@@ -138,7 +139,12 @@ int imap_parse_path (const char *path, IMAP_MBOX *mx)
   {
     return -1;
   }
-  mx->mbox = strchr (path, '}') + 1;
+  c = strchr (path, '}');
+  if (!c)
+    return -1;
+  else
+    /* walk past closing '}' */
+    mx->mbox = strdup (c+1);
   
   /* Defaults */
   mx->flags = 0;
@@ -166,12 +172,7 @@ int imap_parse_path (const char *path, IMAP_MBOX *mx)
     {
 #ifdef USE_SSL
       if (!strcmp (mx->type, "ssl"))
-      {
-	if (! (mx->flags & M_IMAP_PORT))
-	  mx->port = IMAP_SSL_PORT;
-	mx->socktype = M_NEW_SSL_SOCKET;
-	mx->flags |= M_IMAP_TYPE;
-      }
+	imap_set_ssl (mx);
       else
 #endif
       {
@@ -180,7 +181,12 @@ int imap_parse_path (const char *path, IMAP_MBOX *mx)
       }
     }
   }
-  
+
+#ifdef USE_SSL
+  if (option (OPTIMAPFORCESSL))
+    imap_set_ssl (mx);
+#endif
+
   return 0;
 }
 
