@@ -16,7 +16,8 @@
  * 
  *     You should have received a copy of the GNU General Public
  *     License along with this program; if not, write to the Free
- *     Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ *     Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *     Boston, MA  02111, USA.
  */
 
 #include "mutt.h"
@@ -513,7 +514,7 @@ static pgp_key_t *pgp_select_key (pgp_key_t *keys,
 
     case OP_VIEW_ID:
 
-      mutt_message (KeyTable[menu->current]->addr);
+      mutt_message ("%s", KeyTable[menu->current]->addr);
       break;
 
     case OP_GENERIC_SELECT_ENTRY:
